==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/bg-BG/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Аксесоарат е вписан',
    'Accessory_Checkout_Notification' => 'Изписани Аксесоари',
    'Asset_Checkin_Notification' => 'Актива е вписан',
    'Asset_Checkout_Notification' => 'Актива е изписан',
    'Confirm_Accessory_Checkin' => 'Потвърждение при връщане на аксесоар',
    'Confirm_Asset_Checkin' => 'Потвърждение при връщане на актив',
    'Confirm_accessory_delivery' => 'Потвърждение при доставка на аксесоар',
    'Confirm_asset_delivery' => 'Потвърждение при доставка на актив',
    'Confirm_consumable_delivery' => 'Потвърждение при доставка на консуматив',
    'Confirm_license_delivery' => 'Потвърждение при доставка на лиценз',
    'Consumable_checkout_notification' => 'Изписани консумативи',
    'Days' => 'Дни',
    'Expected_Checkin_Date' => 'Наближава срока за връщане на актив който е заведен на Вас, трябва да се върна на :date',
    'Expected_Checkin_Notification' => 'Напомняне: :name крайната дата за вписване наближава',
    'Expected_Checkin_Report' => 'Очакван рапорт за вписване на актив',
    'Expiring_Assets_Report' => 'Доклад за изтичащи активи.',
    'Expiring_Licenses_Report' => 'Доклад за изтичащи лицензи.',
    'Item_Request_Canceled' => 'Заявка за артикул отменена',
    'Item_Requested' => 'Артикул заявен',
    'License_Checkin_Notification' => 'Лиценза е вписан',
    'License_Checkout_Notification' => 'Изписани лицензи',
    'Low_Inventory_Report' => 'Доклад за нисък запас',
    'a_user_canceled' => 'Потребител е отменил заявка за елемент в уебсайта',
    'a_user_requested' => 'Потребител е направил заявка за елемент в уебсайта',
    'acceptance_asset_accepted' => 'Потребителя прие актива',
    'acceptance_asset_declined' => 'Потребителя отказа актива',
    'accessory_name' => 'Аксесоар',
    'additional_notes' => 'Допълнителни бележки',
    'admin_has_created' => 'Администратор е създал акаунт за вас на :web website.',
    'asset' => 'Актив',
    'asset_name' => 'Име на актив',
    'asset_requested' => 'Заявка за актив',
    'asset_tag' => 'Инвентарен номер',
    'assets_warrantee_alert' => 'Има :count актив(а) с гаранция, която ще изтече в следващите :threshold дни.|Има :count активa с гаранции, която ще изтече в следващите :threshold дни.',
    'assigned_to' => 'Възложени на',
    'best_regards' => 'С най-добри пожелания.',
    'canceled' => 'Отменено',
    'checkin_date' => 'Дата на вписване',
    'checkout_date' => 'Дата на изписване',
    'checkedout_from' => 'Изписан от',
    'checkedin_from'  => 'Вписан от',
    'checked_into' => 'Изписан на',
    'click_on_the_link_accessory' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили аксесоара.',
    'click_on_the_link_asset' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили актива.',
    'click_to_confirm' => 'Моля кликнете на следния линк за да потвърдите вашия :web account:',
    'current_QTY' => 'Текуща наличност',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Очаквана дата на вписване',
    'expires' => 'Изтича',
    'hello' => 'Здравейте',
    'hi' => 'Здравейте',
    'i_have_read' => 'Прочетох и се съгласих с условията за ползване, и получих този артикул.',
    'inventory_report' => 'Списък активи',
    'item' => 'Информация',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'Има :count лиценз, който изтича в следващите :threshold дни.|Има :count лиценза, които изтичат в следващите :threshold дни.',
    'link_to_update_password' => 'Моля щракенете върху следния линк за да обновите своята :web password:',
    'login' => 'Вход:',
    'login_first_admin' => 'Влезте в своята Snipe-IT инсталация използвайки данните по-долу:',
    'low_inventory_alert' => 'Има :count артикул, който е под минималния праг за наличност или скоро ще се изчерпа.| Има :count артикула, които са под минималния праг за наличност или скоро ще се изчерпат.',
    'min_QTY' => 'Минимално количество',
    'name' => 'Име',
    'new_item_checked' => 'Нов артикул беше изписан под вашето име, детайлите са отдолу.',
    'notes' => 'Бележки',
    'password' => 'Парола',
    'password_reset' => 'Нулиране на паролата',
    'read_the_terms' => 'Моля прочетете условията по-долу.',
    'read_the_terms_and_click' => 'Моля прочетете условията за ползване по-долу и щракнете върху връзката в края, за да потвърдите че сте прочели и се съгласявате с условията на употреба и сте получили актива.',
    'requested' => 'Изискан',
    'reset_link' => 'Вашата връзка за повторно задаване на паролата',
    'reset_password' => 'Щракнете тук, за да нулирате паролата си:',
    'rights_reserved' => 'Всички права запазени.',
    'serial' => 'Лицензен номер',
    'snipe_webhook_test' => 'Snipe-IT Интеграционен тест',
    'snipe_webhook_summary' => 'Snipe-IT Резюме на интеграционния тест',
    'supplier' => 'Доставчик',
    'tag' => 'Етикет',
    'test_email' => 'Тест Email от Snipe-IT',
    'test_mail_text' => 'Това е тест от Snipe-IT система за управление на активи. Ако сте получили това, email-а работи :)',
    'the_following_item' => 'Следният артикул беше вписан:',
    'to_reset' => 'За да нулирате вашата :web password, попълнете този формуляр:',
    'type' => 'Вид',
    'upcoming-audits' => 'Има :count актив, който подлежи на одит в следващите :threshold дни.|Има :count активи, които подлежат на отид през следващите :threshold дни.',
    'user' => 'Потребител',
    'username' => 'Потребителско име',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Добре дошли, :name',
    'welcome_to' => 'Добре дошли: уеб!',
    'your_assets' => 'Преглед на вашите активи',
    'your_credentials' => 'Вашите идентификационни данни за Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/bg-BG/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Аксесоарат е вписан',
    'Accessory_Checkout_Notification' => 'Accessory checked out|:count Accessories checked out',
    'Asset_Checkin_Notification' => 'Asset checked in: :tag',
    'Asset_Checkout_Notification' => 'Asset checked out: :tag',
    'Confirm_Accessory_Checkin' => 'Потвърждение при връщане на аксесоар',
    'Confirm_Asset_Checkin' => 'Потвърждение при връщане на актив',
    'Confirm_component_checkin' => 'Component checkin confirmation',
    'Confirm_accessory_delivery' => 'Потвърждение при доставка на аксесоар',
    'Confirm_asset_delivery' => 'Потвърждение при доставка на актив',
    'Confirm_consumable_delivery' => 'Потвърждение при доставка на консуматив',
    'Confirm_component_delivery' => 'Component delivery confirmation',
    'Confirm_license_delivery' => 'Потвърждение при доставка на лиценз',
    'Consumable_checkout_notification' => 'Изписани консумативи',
    'Component_checkout_notification' => 'Component checked out',
    'Component_checkin_notification' => 'Component checked in',
    'Days' => 'Дни',
    'Expected_Checkin_Date' => 'Наближава срока за връщане на актив който е заведен на Вас, трябва да се върна на :date',
    'Expected_Checkin_Notification' => 'Напомняне: :name крайната дата за вписване наближава',
    'Expected_Checkin_Report' => 'Очакван рапорт за вписване на актив',
    'Expiring_Assets_Report' => 'Доклад за изтичащи активи',
    'Expiring_Licenses_Report' => 'Доклад за изтичащи лицензи',
    'Item_Request_Canceled' => 'Заявка за артикул отменена',
    'Item_Requested' => 'Артикул заявен',
    'License_Checkin_Notification' => 'Лиценза е вписан',
    'License_Checkout_Notification' => 'Изписани лицензи',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Доклад за нисък запас',
    'a_user_canceled' => 'Потребител е отменил заявка за елемент в уебсайта',
    'a_user_requested' => 'Потребител е направил заявка за елемент в уебсайта',
    'acceptance_asset_accepted_to_user' => 'You have accepted an item assigned to you by :site_name|You have accepted :qty items assigned to you by :site_name',
    'acceptance_asset_accepted' => 'Потребителя прие актива',
    'acceptance_asset_declined' => 'Потребителя отказа актива',
    'send_pdf_copy' => 'Send a copy of this acceptance to my email address',
    'accessory_name' => 'Аксесоар',
    'additional_notes' => 'Допълнителни бележки',
    'admin_has_created' => 'An administrator has created an account for you on the :web website. Please find your username below, and click on the link to set a password.',
    'asset' => 'Актив',
    'asset_name' => 'Име на актив',
    'asset_requested' => 'Заявка за актив',
    'asset_tag' => 'Инвентарен номер',
    'assets_warrantee_alert' => 'There is :count asset with an expiring warranty or that are reaching their end of life in the next :threshold days.|There are :count assets with expiring warranties or that are reaching their end of life in the next :threshold days.',
    'assigned_to' => 'Възложени на',
    'eol' => 'EOL',
    'best_regards' => 'С най-добри пожелания.',
    'canceled' => 'Отменено',
    'checkin_date' => 'Дата на вписване',
    'checkout_date' => 'Дата на изписване',
    'checkedout_from' => 'Изписан от',
    'checkedin_from'  => 'Вписан от',
    'checked_into' => 'Изписан на',
    'click_on_the_link_accessory' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили аксесоара.',
    'click_on_the_link_asset' => 'Моля, кликнете върху връзката в дъното, за да потвърдите, че сте получили актива.',
    'click_to_confirm' => 'Моля кликнете на следния линк за да потвърдите вашия :web account:',
    'current_QTY' => 'Текуща наличност',
    'days' => 'Дни',
    'expecting_checkin_date' => 'Очаквана дата на вписване',
    'expires' => 'Изтича',
    'terminates' => 'Terminates',
    'following_accepted' => 'The following was accepted',
    'following_declined' => 'The following was declined',
    'hello' => 'Здравейте',
    'hi' => 'Здравейте',
    'i_have_read' => 'Прочетох и се съгласих с условията за ползване, и получих този артикул.',
    'initiated_accepted' => 'A checkout you initiated was accepted',
    'initiated_declined' => 'A checkout you initiated was declined',
    'inventory_report' => 'Списък активи',
    'item' => 'Информация',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => 'There is :count license expiring or terminating in the next :threshold days.|There are :count licenses expiring or terminating in the next :threshold days.',
    'link_to_update_password' => 'Моля щракенете върху следния линк за да обновите своята :web password:',
    'login' => 'Логин',
    'login_first_admin' => 'Влезте в своята Snipe-IT инсталация използвайки данните по-долу:',
    'low_inventory_alert' => 'Има :count артикул, който е под минималния праг за наличност или скоро ще се изчерпа.| Има :count артикула, които са под минималния праг за наличност или скоро ще се изчерпат.',
    'min_QTY' => 'Минимално количество',
    'name' => 'Име',
    'new_item_checked' => 'A new item has been checked out under your name, details are below.|:count new items have been checked out under your name, details are below.',
    'new_item_checked_with_acceptance' => 'A new item has been checked out under your name that requires acceptance, details are below.|:count new items have been checked out under your name that requires acceptance, details are below.',
    'new_item_checked_location' => 'A new item has been checked out to :location, details are below.|:count new items have been checked out to :location, details are below.',
    'recent_item_checked' => 'An item was recently checked out under your name that requires acceptance, details are below.',
    'notes' => 'Бележки',
    'password' => 'Парола',
    'password_reset' => 'Нулиране на паролата',
    'read_the_terms' => 'Моля прочетете условията по-долу.',
    'read_the_terms_and_click' => 'Моля прочетете условията за ползване по-долу и щракнете върху връзката в края, за да потвърдите че сте прочели и се съгласявате с условията на употреба и сте получили актива.',
    'requested' => 'Изискан',
    'reset_link' => 'Вашата връзка за повторно задаване на паролата',
    'reset_password' => 'Щракнете тук, за да нулирате паролата си:',
    'rights_reserved' => 'Всички права запазени.',
    'serial' => 'Лицензен номер',
    'snipe_webhook_test' => 'Snipe-IT Интеграционен тест',
    'snipe_webhook_summary' => 'Snipe-IT Резюме на интеграционния тест',
    'supplier' => 'Доставчик',
    'tag' => 'Етикет',
    'test_email' => 'Тест Email от Snipe-IT',
    'test_mail_text' => 'Това е тест от Snipe-IT система за управление на активи. Ако сте получили това, email-а работи :)',
    'the_following_item' => 'Следният артикул беше вписан:',
    'to_reset' => 'За да нулирате вашата :web password, попълнете този формуляр:',
    'type' => 'Вид',
    'upcoming-audits' => 'Има :count актив, който подлежи на одит в следващите :threshold дни.|Има :count активи, които подлежат на отид през следващите :threshold дни.',
    'user' => 'Потребител',
    'username' => 'Потребителско име',
    'unaccepted_asset_reminder' => 'Reminder: You have Unaccepted Assets.',
    'welcome' => 'Добре дошли, :name',
    'welcome_to' => 'Добре дошли: уеб!',
    'your_assets' => 'Преглед на вашите активи',
    'your_credentials' => 'Вашите идентификационни данни за Snipe-IT',
    'mail_sent' => 'Mail sent successfully!',
];
